
function [x,iter] = Gauss(A,b)

%_________________________________________________________________________
%
% Funzione: Gauss
% ____________________
%
% Chiamata:  [x,iter] = Gauss(A,b);
%
% La function 'Gauss' risolve un sistema lineare Ax=b attraverso  
% la fattorizzazione LU della matrice A, (senza pivotazione) e 
% esegue poi il raffinamento iterativo della soluzione.
% 
%
% Parametri in ingresso:
% ______________________
%
%  A   matrice del sistema, di dimensione nxn;
%  b   vettore colonna, di lunghezza n, contenente il termine noto
%      del sistema.
%
%
% Parametri in uscita:
% ____________________
%
%  x       vettore colonna di lunghezza n, contenente la soluzione del
%          sistema;
%  iter    numero di iterazioni effettuate dal raffinamento iterativo.
%
%
%  La function richiama: Lufact, Forwsub, Backsub, Raff_iter.
%_________________________________________________________________________
%
% Esempio di utilizzo della function applicata al sistema lineare Ax=b 
% dove
%
% A=     5  -2   0
%       -2   5  -2
%        0  -2   5
%
% b=     3
%        1
%        3
% 
% con soluzione vera:
%
% alpha= 1
%        1
%        1
%_________________________________________________________________________
% 
% clear all; clc
% n=3;
% A=5*eye(n)-2*diag(ones(n-1,1),-1)-2*diag(ones(n-1,1),1)
% b=[3 1 3]'
%
% [x,iter] = Gauss(A,b)
%
%_________________________________________________________________________

[L,U] = Lufact(A);
[y] = Forwsub(L,b);
[x] = Backsub(U,y);
P=eye(size(A));
R=P;
[x,iter]=Raff_iter(A,b,L,U,P,R,x);
