
function [x,iter] = Gausspv_t(A,b)

%______________________________________________________________________
%
% Funzione: Gausspv_t
% ______________________
%
% Chiamata:  [x,iter] = Gausspv_t(A,b);
%
% La function 'Gausspv_t' risolve un sistema lineare Ax=b 
% attraverso la fattorizzazione LU della matrice PAR 
% (pivotazione totale) e esegue poi il raffinamento iterativo
% della soluzione; P e R sono matrici di permutazione.
%
%    Ax=b      PAR=LU  =>   Ly=Pb
%                           Uz=y
%                           x=Rz
%
% Parametri in ingresso:
% ______________________
%
%  A   matrice del sistema, di dimensione nxn;
%  b   vettore colonna di lunghezza n, contenente il termine noto
%      del sistema. 
%
% Parametri in uscita:
% _____________________
%
%  x    vettore colonna di lunghezza n, contenente la soluzione del
%       sistema;
%  iter numero di iterazioni effettuate dal raffinamento iterativo.
%
%
%  La function richiama: Lufpiv_t, Forwsub, Backsub, Raff_iter.
%
%____________________________________________________________________
%
% Esempio di utilizzo della function applicata al sistema lineare Ax=b 
% dove
%
% A=     5  -2   0
%       -2   5  -2
%        0  -2   5
%
% b=     3
%        1
%        3
% 
% con soluzione vera:
%
% alpha= 1
%        1
%        1
%___________________________________________________________________
% 
% clear all; clc
% n=3;
% A=5*eye(n)-2*diag(ones(n-1,1),-1)-2*diag(ones(n-1,1),1)
% b=[3 1 3]'
%
% [x,iter] = Gausspv_t(A,b)
%
%___________________________________________________________________


[L,U,P,R] = Lufpiv_t(A);
[y] = Forwsub(L,P*b);
[z] = Backsub(U,y);
x=R*z;
[x,iter]=Raff_iter(A,b,L,U,P,R,x);
