
function [L,U,P,R] = Lufpiv_t(A)

%_______________________________________________________________
%
%  Funzione: Lufpiv_t
%  _____________________
%
%  Chiamata:  [L,U,P,R] = Lufpiv_t(A)
%
%  La function 'Lufpiv_t' esegue la fattorizzazione LU con 
%  pivotazione totale.
%
%            PAR=LU
%
%  Parametri in ingresso:
%  ______________________
%
%   A    matrice di dimensione nxn da fattorizzare;
%
%  Parametri in uscita:
%  ____________________
%
%   L     matrice triangolare inferiore di dimensione nxn;
%   U     matrice triangolare superiore di dimensione nxn;
%   P,R   matrici di permutazione di dimensione nxn.
%
%_______________________________________________________________


a=A;
if abs(det(a))<10^-14
   disp('Matrice A singolare')
else
   [n,m]=size(a);
   for k=1:m-1
%
%   ricerca dell'elemento di modulo massimo (e del suo indice
%   di riga e di colonna) nella sottomatrice formata 
%   dall'intersezione delle ultime k righe e k colonne di A 
%   modificata ad ogni passo del metodo.
%
       [riga,p]=max(abs(a(k:n,k:n)));
       [col,q]=max(riga);
       p=p(q)+k-1;
       q=q+k-1;
       r(k)=p;
       c(k)=q;
%
%   Scambio tra la riga k e la riga p
%
   	aa=a(k,:);
	   a(k,:)=a(p,:);
      a(p,:)=aa;
%
%   Scambio tra la colonna k e la colonna q
%
      aa=a(:,k);
      a(:,k)=a(:,q);
      a(:,q)=aa;   
%
%   Azzeramento degli elementi a(i,k)
%
      for i=k+1:n
         mik=-a(i,k)/a(k,k);
		   a(i,k)=-mik;
		   for j=k+1:n
   			a(i,j)=a(i,j)+mik*a(k,j);
	   	end
	   end   
   end            
%
%  Costruzione delle matrici L, U, P, R
%
   L=tril(a,-1)+eye(n);
   U=triu(a);
   
   P=eye(n);
   for k=n-1:-1:1
      I=eye(n);
      aa=I(k,:);
      I(k,:)=I(r(k),:);
      I(r(k),:)=aa;
      P=P*I;
   end
   
   R=eye(n);
   for k=1:n-1
      I=eye(n);
      aa=I(:,k);
      I(:,k)=I(:,c(k));
      I(:,c(k))=aa;
      R=R*I;
   end
end  


